@@ -1,27 +1,32 @@
-from cnvrg.modules.cnvrg_job import CnvrgJob, LOGS_TYPE_OUTPUT, LOGS_TYPE_ERROR
-import cnvrg.helpers.param_build_helper as param_build_helper
-from cnvrg.modules.project import Project
-import cnvrg.helpers.logger_helper as logger_helper
-import cnvrg.helpers.string_helper as string_helper
-from cnvrg.modules.errors import UserError
-import cnvrg.helpers.apis_helper as apis_helper
-import cnvrg.helpers.spawn_helper as spawn_helper
-import cnvrg.helpers.control_stdout_helper as control_stdout_helper
-import cnvrg.helpers.env_helper as env_helper
-import cnvrg.helpers.chart_show_helper as chart_show_helper
-from cnvrg.helpers.env_helper import in_experiment
-from cnvrg.helpers.url_builder_helper import url_join
-from cnvrg.modules.mixins.charts_mixin import ChartsMixin
-from cnvrg.helpers.param_helper import wrap_string_to_list
-from cnvrg.helpers.libs_helper import check_if_lib_exists
-from cnvrg.modules.errors import CnvrgError
-from enum import Enum
-from typing import List, AnyStr
-from cnvrg.helpers.error_catcher import suppress_exception
-import numpy as np
-import types
 import os
 import time
+import types
+import threading
+import numpy as np
+
+from enum import Enum
+from typing import List, AnyStr
+
+from cnvrg.modules.project import Project
+from cnvrg.modules.errors import UserError
+from cnvrg.modules.errors import CnvrgError
+from cnvrg.helpers.async_runner import AsyncRunner
+from cnvrg.helpers.env_helper import in_experiment
+from cnvrg.helpers.url_builder_helper import url_join
+from cnvrg.helpers.libs_helper import check_if_lib_exists
+from cnvrg.modules.mixins.charts_mixin import ChartsMixin
+from cnvrg.helpers.error_catcher import suppress_exception
+from cnvrg.helpers.param_helper import wrap_string_to_list
+from cnvrg.modules.cnvrg_job import CnvrgJob, LOGS_TYPE_OUTPUT, LOGS_TYPE_ERROR
+
+import cnvrg.helpers.env_helper as env_helper
+import cnvrg.helpers.apis_helper as apis_helper
+import cnvrg.helpers.spawn_helper as spawn_helper
+import cnvrg.helpers.logger_helper as logger_helper
+import cnvrg.helpers.string_helper as string_helper
+import cnvrg.helpers.chart_show_helper as chart_show_helper
+import cnvrg.helpers.param_build_helper as param_build_helper
+import cnvrg.helpers.control_stdout_helper as control_stdout_helper
 
 
 class TagType(Enum):
@@ -40,6 +45,7 @@ class Experiment(CnvrgJob, ChartsMixin):
         self.__data = self.__get_experiment()
         self.chart_metrics = {}
 
+
     @staticmethod
     @suppress_exception
     def _create_clean_experiment(project=None, **kwargs):
@@ -54,6 +60,10 @@ class Experiment(CnvrgJob, ChartsMixin):
         exp.set_as_default()
         return exp
 
+    @staticmethod
+    def init(project=None, **kwargs):
+        return Experiment._create_clean_experiment(project=project, **kwargs)
+
     def notify_running(self):
         logger_helper.log_message(
             "{title} is running, follow live at: {url}".format(title=self['title'], url=self.href()))
@@ -168,7 +178,7 @@ class Experiment(CnvrgJob, ChartsMixin):
         return mapped_files
 
     @staticmethod
-    def run(command=None, arguments: dict=None, grid: dict=None, title: str=None, project: Project=None, compute: str=None, output_dir: str=None, computes: List=None,
+    def     run(command=None, arguments: dict=None, grid: dict=None, title: str=None, project: Project=None, compute: str=None, output_dir: str=None, computes: List=None,
             datasets: List=None, dataset: str=None, local: bool=False, library: str=None, working_directory: str=None, sync_before: bool=True, sync_after: bool=True,
             prerun: bool=True, requirements: bool=True, image: str=None, schedule: str=None, recurring: str=None, git_commit: str=None, git_branch: str=None,
             local_folders: List=None, notify_on_error: bool=False, notify_on_success: bool=False, emails_to_notify: List=None, **kwargs):
@@ -250,8 +260,13 @@ class Experiment(CnvrgJob, ChartsMixin):
             logger_helper.log_warn("Can't run a function command on remote experiment. please use local compute instead.")
             raise UserError("Can't run a function command on remote experiment. please use local compute instead.")
 
+    def log_param(self, key, value=None, run_async=True):
+        if run_async:
+            AsyncRunner(self._log_param).run(key, value)
+        else:
+            self._log_param(key, value)
 
-    def log_param(self, key, value=None):
+    def _log_param(self, key, value=None):
         tag_data = {
             "key": key,
             "value": value,
@@ -262,7 +277,13 @@ class Experiment(CnvrgJob, ChartsMixin):
     def __dict__(self):
         return self.__data
 
-    def log_metric(self, key, Ys: List, Xs: List=None, grouping: List=None, x_axis=None, y_axis=None) -> None:
+    def log_metric(self, key, Ys: List, Xs: List=None, grouping: List=None, x_axis=None, y_axis=None, run_async=True) -> None:
+        if run_async:
+            AsyncRunner(self._log_metric).run(key, Ys, Xs, grouping, x_axis, y_axis)
+        else:
+            self._log_metric(key, Ys, Xs, grouping, x_axis, y_axis)
+
+    def _log_metric(self, key, Ys: List, Xs: List=None, grouping: List=None, x_axis=None, y_axis=None) -> None:
         """
         a function which can tag an experiment with a chart
         :param key: the name of the chart
@@ -341,8 +362,7 @@ class Experiment(CnvrgJob, ChartsMixin):
         resp = apis_helper.get(url_join(self._base_url(), 'logs'), data={"offset": offset, "limit": limit})
         return resp.get("logs"), resp.get("experiment").get("is_running")
 
-    @suppress_exception
-    def __send_tag(self,tag_data):
+    def __send_tag(self, tag_data):
         apis_helper.post(url_join(self._base_url(), 'tags'), data={"tag": tag_data})
 
     @suppress_exception
